==> sumus-6.3.3-sources.jar: io/intino/sumus/graph/TemporalMetric.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class TemporalMetric extends io.intino.sumus.graph.AbstractMetric implements io.intino.tara.magritte.tags.Terminal {



	public TemporalMetric(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.util.List<io.intino.sumus.graph.TemporalMetric.Unit> temporalMetricUnitList() {
		return new io.intino.tara.magritte.utils.ProxyList<>(unitList, io.intino.sumus.graph.TemporalMetric.Unit.class);
	}

	public io.intino.sumus.graph.TemporalMetric.Unit temporalMetricUnit(int index) {
		return temporalMetricUnitList().get(index);
	}

	public java.util.List<io.intino.sumus.graph.TemporalMetric.Unit> temporalMetricUnitList(java.util.function.Predicate<io.intino.sumus.graph.TemporalMetric.Unit> predicate) {
		return temporalMetricUnitList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());

		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);

	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);

    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.AbstractMetric.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.TemporalMetric.Unit unit(double limit, double conversionFactor) {
		    io.intino.sumus.graph.TemporalMetric.Unit newElement = core$().graph().concept(io.intino.sumus.graph.TemporalMetric.Unit.class).createNode(name, core$()).as(io.intino.sumus.graph.TemporalMetric.Unit.class);
			newElement.core$().set(newElement, "limit", java.util.Collections.singletonList(limit));
			newElement.core$().set(newElement, "conversionFactor", java.util.Collections.singletonList(conversionFactor));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear extends io.intino.sumus.graph.AbstractMetric.Clear {

	}

	public static class Unit extends io.intino.sumus.graph.AbstractMetric.Unit implements io.intino.tara.magritte.tags.Terminal {
		protected double limit;
		protected double conversionFactor;

		public Unit(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public double limit() {
			return limit;
		}

		public double conversionFactor() {
			return conversionFactor;
		}

		public Unit limit(double value) {
			this.limit = value;
			return (Unit) this;
		}

		public Unit conversionFactor(double value) {
			this.conversionFactor = value;
			return (Unit) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			map.put("limit", new java.util.ArrayList(java.util.Collections.singletonList(this.limit)));
			map.put("conversionFactor", new java.util.ArrayList(java.util.Collections.singletonList(this.conversionFactor)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("limit")) this.limit = io.intino.tara.magritte.loaders.DoubleLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("conversionFactor")) this.conversionFactor = io.intino.tara.magritte.loaders.DoubleLoader.load(values, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("limit")) this.limit = (java.lang.Double) values.get(0);
			else if (name.equalsIgnoreCase("conversionFactor")) this.conversionFactor = (java.lang.Double) values.get(0);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-7.2.1-sources.jar: io/intino/sumus/graph/TemporalMetric.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class TemporalMetric extends io.intino.sumus.graph.AbstractMetric implements io.intino.tara.magritte.tags.Terminal {



	public TemporalMetric(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.util.List<io.intino.sumus.graph.TemporalMetric.Unit> temporalMetricUnitList() {
		return new io.intino.tara.magritte.utils.ProxyList<>(unitList, io.intino.sumus.graph.TemporalMetric.Unit.class);
	}

	public io.intino.sumus.graph.TemporalMetric.Unit temporalMetricUnit(int index) {
		return temporalMetricUnitList().get(index);
	}

	public java.util.List<io.intino.sumus.graph.TemporalMetric.Unit> temporalMetricUnitList(java.util.function.Predicate<io.intino.sumus.graph.TemporalMetric.Unit> predicate) {
		return temporalMetricUnitList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());

		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);

	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);

    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.AbstractMetric.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.TemporalMetric.Unit unit(double limit, double conversionFactor) {
		    io.intino.sumus.graph.TemporalMetric.Unit newElement = core$().graph().concept(io.intino.sumus.graph.TemporalMetric.Unit.class).createNode(this.name, core$()).as(io.intino.sumus.graph.TemporalMetric.Unit.class);
			newElement.core$().set(newElement, "limit", java.util.Collections.singletonList(limit));
			newElement.core$().set(newElement, "conversionFactor", java.util.Collections.singletonList(conversionFactor));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear extends io.intino.sumus.graph.AbstractMetric.Clear {

	}

	public static class Unit extends io.intino.sumus.graph.AbstractMetric.Unit implements io.intino.tara.magritte.tags.Terminal {
		protected double limit;
		protected double conversionFactor;

		public Unit(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public double limit() {
			return limit;
		}

		public double conversionFactor() {
			return conversionFactor;
		}

		public Unit limit(double value) {
			this.limit = value;
			return (Unit) this;
		}

		public Unit conversionFactor(double value) {
			this.conversionFactor = value;
			return (Unit) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			map.put("limit", new java.util.ArrayList(java.util.Collections.singletonList(this.limit)));
			map.put("conversionFactor", new java.util.ArrayList(java.util.Collections.singletonList(this.conversionFactor)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("limit")) this.limit = io.intino.tara.magritte.loaders.DoubleLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("conversionFactor")) this.conversionFactor = io.intino.tara.magritte.loaders.DoubleLoader.load(values, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("limit")) this.limit = (java.lang.Double) values.get(0);
			else if (name.equalsIgnoreCase("conversionFactor")) this.conversionFactor = (java.lang.Double) values.get(0);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
